==> libdatetime-locale-perl_1.23.orig.tar.gz: DateTime-Locale-1.23/share/ku.pl <==
{
  am_pm_abbreviated => [
    "AM",
    "PM",
  ],
  available_formats => {
    Bh => "h B",
    Bhm => "h:mm B",
    Bhms => "h:mm:ss B",
    E => "ccc",
    EBhm => "E h:mm B",
    EBhms => "E h:mm:ss B",
    EHm => "E HH:mm",
    EHms => "E HH:mm:ss",
    Ed => "d, E",
    Ehm => "E h:mm a",
    Ehms => "E h:mm:ss a",
    Gy => "G y",
    GyMMM => "G y MMM",
    GyMMMEd => "G y MMM d, E",
    GyMMMd => "G y MMM d",
    H => "HH",
    Hm => "HH:mm",
    Hms => "HH:mm:ss",
    Hmsv => "HH:mm:ss v",
    Hmv => "HH:mm v",
    M => "L",
    MEd => "MM-dd, E",
    MMM => "LLL",
    MMMEd => "MMM d, E",
    "MMMMW-count-other" => "'week' W 'of' MMMM",
    MMMMd => "MMMM d",
    MMMd => "MMM d",
    Md => "MM-dd",
    d => "d",
    h => "h a",
    hm => "h:mm a",
    hms => "h:mm:ss a",
    hmsv => "h:mm:ss a v",
    hmv => "h:mm a v",
    ms => "mm:ss",
    y => "y",
    yM => "y-MM",
    yMEd => "y-MM-dd, E",
    yMMM => "y MMM",
    yMMMEd => "y MMM d, E",
    yMMMM => "y MMMM",
    yMMMd => "y MMM d",
    yMd => "y-MM-dd",
    yQQQ => "y QQQ",
    yQQQQ => "y QQQQ",
    "yw-count-other" => "'week' w 'of' Y",
  },
  code => "ku",
  date_format_full => "y MMMM d, EEEE",
  date_format_long => "y MMMM d",
  date_format_medium => "y MMM d",
  date_format_short => "y-MM-dd",
  datetime_format_full => "{1} {0}",
  datetime_format_long => "{1} {0}",
  datetime_format_medium => "{1} {0}",
  datetime_format_short => "{1} {0}",
  day_format_abbreviated => [
    "d\N{U+015f}",
    "s\N{U+015f}",
    "\N{U+00e7}\N{U+015f}",
    "p\N{U+015f}",
    "\N{U+00ee}n",
    "\N{U+015f}",
    "y\N{U+015f}",
  ],
  day_format_narrow => [
    "D",
    "S",
    "\N{U+00c7}",
    "P",
    "\N{U+00ce}",
    "\N{U+015e}",
    "Y",
  ],
  day_format_wide => [
    "du\N{U+015f}em",
    "s\N{U+00ea}\N{U+015f}em",
    "\N{U+00e7}ar\N{U+015f}em",
    "p\N{U+00ea}nc\N{U+015f}em",
    "\N{U+00ee}n",
    "\N{U+015f}em\N{U+00ee}",
    "yek\N{U+015f}em",
  ],
  day_stand_alone_abbreviated => [
    "d\N{U+015f}",
    "s\N{U+015f}",
    "\N{U+00e7}\N{U+015f}",
    "p\N{U+015f}",
    "\N{U+00ee}n",
    "\N{U+015f}",
    "y\N{U+015f}",
  ],
  day_stand_alone_narrow => [
    "D",
    "S",
    "\N{U+00c7}",
    "P",
    "\N{U+00ce}",
    "\N{U+015e}",
    "Y",
  ],
  day_stand_alone_wide => [
    "du\N{U+015f}em",
    "s\N{U+00ea}\N{U+015f}em",
    "\N{U+00e7}ar\N{U+015f}em",
    "p\N{U+00ea}nc\N{U+015f}em",
    "\N{U+00ee}n",
    "\N{U+015f}em\N{U+00ee}",
    "yek\N{U+015f}em",
  ],
  era_abbreviated => [
    "BZ",
    "PZ",
  ],
  era_narrow => [
    "BZ",
    "PZ",
  ],
  era_wide => [
    "ber\N{U+00ee} zay\N{U+00ee}n\N{U+00ea}",
    "pi\N{U+015f}t\N{U+00ee} zay\N{U+00ee}n\N{U+00ea}",
  ],
  first_day_of_week => 1,
  glibc_date_1_format => "%a %b %e %H:%M:%S %Z %Y",
  glibc_date_format => "%m/%d/%y",
  glibc_datetime_format => "%a %b %e %H:%M:%S %Y",
  glibc_time_12_format => "%I:%M:%S %p",
  glibc_time_format => "%H:%M:%S",
  language => "Kurdish",
  month_format_abbreviated => [
    "r\N{U+00ea}b",
    "re\N{U+015f}",
    "ada",
    "avr",
    "gul",
    "p\N{U+00fb}\N{U+015f}",
    "t\N{U+00ee}r",
    "gel",
    "rez",
    "kew",
    "ser",
    "ber",
  ],
  month_format_narrow => [
    "R",
    "R",
    "A",
    "A",
    "G",
    "P",
    "T",
    "G",
    "R",
    "K",
    "S",
    "B",
  ],
  month_format_wide => [
    "r\N{U+00ea}bendan\N{U+00ea}",
    "re\N{U+015f}emiy\N{U+00ea}",
    "adar\N{U+00ea}",
    "avr\N{U+00ea}l\N{U+00ea}",
    "gulan\N{U+00ea}",
    "p\N{U+00fb}\N{U+015f}per\N{U+00ea}",
    "t\N{U+00ee}rmeh\N{U+00ea}",
    "gelaw\N{U+00ea}j\N{U+00ea}",
    "rezber\N{U+00ea}",
    "kew\N{U+00e7}\N{U+00ea}r\N{U+00ea}",
    "sermawez\N{U+00ea}",
    "berfanbar\N{U+00ea}",
  ],
  month_stand_alone_abbreviated => [
    "r\N{U+00ea}b",
    "re\N{U+015f}",
    "ada",
    "avr",
    "gul",
    "p\N{U+00fb}\N{U+015f}",
    "t\N{U+00ee}r",
    "gel",
    "rez",
    "kew",
    "ser",
    "ber",
  ],
  month_stand_alone_narrow => [
    "R",
    "R",
    "A",
    "A",
    "G",
    "P",
    "T",
    "G",
    "R",
    "K",
    "S",
    "B",
  ],
  month_stand_alone_wide => [
    "r\N{U+00ea}bendan",
    "re\N{U+015f}em\N{U+00ee}",
    "adar",
    "avr\N{U+00ea}l",
    "gulan",
    "p\N{U+00fb}\N{U+015f}per",
    "t\N{U+00ee}rmeh",
    "gelaw\N{U+00ea}j",
    "rezber",
    "kew\N{U+00e7}\N{U+00ea}r",
    "sermawez",
    "berfanbar",
  ],
  name => "Kurdish",
  native_language => "kurd\N{U+00ee}",
  native_name => "kurd\N{U+00ee}",
  native_script => undef,
  native_territory => undef,
  native_variant => undef,
  quarter_format_abbreviated => [
    "\N{U+00c7}1",
    "\N{U+00c7}2",
    "\N{U+00c7}3",
    "\N{U+00c7}4",
  ],
  quarter_format_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_format_wide => [
    "Q1",
    "Q2",
    "Q3",
    "Q4",
  ],
  quarter_stand_alone_abbreviated => [
    "\N{U+00c7}1",
    "\N{U+00c7}2",
    "\N{U+00c7}3",
    "\N{U+00c7}4",
  ],
  quarter_stand_alone_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_stand_alone_wide => [
    "Q1",
    "Q2",
    "Q3",
    "Q4",
  ],
  script => undef,
  territory => undef,
  time_format_full => "HH:mm:ss zzzz",
  time_format_long => "HH:mm:ss z",
  time_format_medium => "HH:mm:ss",
  time_format_short => "HH:mm",
  variant => undef,
  version => 34,
}

==> libdatetime-locale-perl_1.37.orig.tar.gz: DateTime-Locale-1.37/share/ku.pl <==
{
  am_pm_abbreviated => [
    "BN",
    "PN",
  ],
  available_formats => {
    Bh => "h B",
    Bhm => "h:mm B",
    Bhms => "h:mm:ss B",
    E => "ccc",
    EBhm => "E h:mm B",
    EBhms => "E h:mm:ss B",
    EHm => "E HH:mm",
    EHms => "E HH:mm:ss",
    Ed => "d, E",
    Ehm => "E h:mm a",
    Ehms => "E h:mm:ss a",
    Gy => "G y",
    GyMMM => "G y MMM",
    GyMMMEd => "G y MMM d, E",
    GyMMMd => "G y MMM d",
    GyMd => "GGGGG y-MM-dd",
    H => "HH",
    Hm => "HH:mm",
    Hms => "HH:mm:ss",
    Hmsv => "HH:mm:ss v",
    Hmv => "HH:mm v",
    M => "L",
    MEd => "MM-dd, E",
    MMM => "LLL",
    MMMEd => "MMM d, E",
    "MMMMW-count-other" => "'week' W 'of' MMMM",
    MMMMd => "MMMM d",
    MMMd => "MMM d",
    Md => "MM-dd",
    d => "d",
    h => "h a",
    hm => "h:mm a",
    hms => "h:mm:ss a",
    hmsv => "h:mm:ss a v",
    hmv => "h:mm a v",
    ms => "mm:ss",
    y => "y",
    yM => "y-MM",
    yMEd => "y-MM-dd, E",
    yMMM => "y MMM",
    yMMMEd => "y MMM d, E",
    yMMMM => "y MMMM",
    yMMMd => "y MMM d",
    yMd => "y-MM-dd",
    yQQQ => "y QQQ",
    yQQQQ => "y QQQQ",
    "yw-count-other" => "'week' w 'of' Y",
  },
  code => "ku",
  date_format_full => "y MMMM d, EEEE",
  date_format_long => "y MMMM d",
  date_format_medium => "y MMM d",
  date_format_short => "y-MM-dd",
  datetime_format_full => "{1} {0}",
  datetime_format_long => "{1} {0}",
  datetime_format_medium => "{1} {0}",
  datetime_format_short => "{1} {0}",
  day_format_abbreviated => [
    "d\N{U+015f}",
    "s\N{U+015f}",
    "\N{U+00e7}\N{U+015f}",
    "p\N{U+015f}",
    "\N{U+00ee}n",
    "\N{U+015f}",
    "y\N{U+015f}",
  ],
  day_format_narrow => [
    "D",
    "S",
    "\N{U+00c7}",
    "P",
    "\N{U+00ce}",
    "\N{U+015e}",
    "Y",
  ],
  day_format_wide => [
    "du\N{U+015f}em",
    "s\N{U+00ea}\N{U+015f}em",
    "\N{U+00e7}ar\N{U+015f}em",
    "p\N{U+00ea}nc\N{U+015f}em",
    "\N{U+00ee}n",
    "\N{U+015f}em\N{U+00ee}",
    "yek\N{U+015f}em",
  ],
  day_stand_alone_abbreviated => [
    "d\N{U+015f}",
    "s\N{U+015f}",
    "\N{U+00e7}\N{U+015f}",
    "p\N{U+015f}",
    "\N{U+00ee}n",
    "\N{U+015f}",
    "y\N{U+015f}",
  ],
  day_stand_alone_narrow => [
    "D",
    "S",
    "\N{U+00c7}",
    "P",
    "\N{U+00ce}",
    "\N{U+015e}",
    "Y",
  ],
  day_stand_alone_wide => [
    "du\N{U+015f}em",
    "s\N{U+00ea}\N{U+015f}em",
    "\N{U+00e7}ar\N{U+015f}em",
    "p\N{U+00ea}nc\N{U+015f}em",
    "\N{U+00ee}n",
    "\N{U+015f}em\N{U+00ee}",
    "yek\N{U+015f}em",
  ],
  era_abbreviated => [
    "BZ",
    "PZ",
  ],
  era_narrow => [
    "BZ",
    "PZ",
  ],
  era_wide => [
    "ber\N{U+00ee} zay\N{U+00ee}n\N{U+00ea}",
    "pi\N{U+015f}t\N{U+00ee} zay\N{U+00ee}n\N{U+00ea}",
  ],
  first_day_of_week => 1,
  glibc_date_1_format => "%a %b %e %H:%M:%S %Z %Y",
  glibc_date_format => "%m/%d/%y",
  glibc_datetime_format => "%a %b %e %H:%M:%S %Y",
  glibc_time_12_format => "%I:%M:%S %p",
  glibc_time_format => "%H:%M:%S",
  language => "Kurdish",
  month_format_abbreviated => [
    "r\N{U+00ea}b",
    "re\N{U+015f}",
    "ada",
    "avr",
    "gul",
    "p\N{U+00fb}\N{U+015f}",
    "t\N{U+00ee}r",
    "gel",
    "rez",
    "kew",
    "ser",
    "ber",
  ],
  month_format_narrow => [
    "R",
    "R",
    "A",
    "A",
    "G",
    "P",
    "T",
    "G",
    "R",
    "K",
    "S",
    "B",
  ],
  month_format_wide => [
    "r\N{U+00ea}bendan\N{U+00ea}",
    "re\N{U+015f}emiy\N{U+00ea}",
    "adar\N{U+00ea}",
    "avr\N{U+00ea}l\N{U+00ea}",
    "gulan\N{U+00ea}",
    "p\N{U+00fb}\N{U+015f}per\N{U+00ea}",
    "t\N{U+00ee}rmeh\N{U+00ea}",
    "gelaw\N{U+00ea}j\N{U+00ea}",
    "rezber\N{U+00ea}",
    "kew\N{U+00e7}\N{U+00ea}r\N{U+00ea}",
    "sermawez\N{U+00ea}",
    "berfanbar\N{U+00ea}",
  ],
  month_stand_alone_abbreviated => [
    "r\N{U+00ea}b",
    "re\N{U+015f}",
    "ada",
    "avr",
    "gul",
    "p\N{U+00fb}\N{U+015f}",
    "t\N{U+00ee}r",
    "gel",
    "rez",
    "kew",
    "ser",
    "ber",
  ],
  month_stand_alone_narrow => [
    "R",
    "R",
    "A",
    "A",
    "G",
    "P",
    "T",
    "G",
    "R",
    "K",
    "S",
    "B",
  ],
  month_stand_alone_wide => [
    "r\N{U+00ea}bendan",
    "re\N{U+015f}em\N{U+00ee}",
    "adar",
    "avr\N{U+00ea}l",
    "gulan",
    "p\N{U+00fb}\N{U+015f}per",
    "t\N{U+00ee}rmeh",
    "gelaw\N{U+00ea}j",
    "rezber",
    "kew\N{U+00e7}\N{U+00ea}r",
    "sermawez",
    "berfanbar",
  ],
  name => "Kurdish",
  native_language => "kurd\N{U+00ee}",
  native_name => "kurd\N{U+00ee}",
  native_script => undef,
  native_territory => undef,
  native_variant => undef,
  quarter_format_abbreviated => [
    "\N{U+00c7}1",
    "\N{U+00c7}2",
    "\N{U+00c7}3",
    "\N{U+00c7}4",
  ],
  quarter_format_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_format_wide => [
    "\N{U+00c7}ar\N{U+00ea}ka 1em",
    "\N{U+00c7}ar\N{U+00ea}ka 2em",
    "\N{U+00c7}ar\N{U+00ea}ka 3em",
    "\N{U+00c7}ar\N{U+00ea}ka 4em",
  ],
  quarter_stand_alone_abbreviated => [
    "\N{U+00c7}1",
    "\N{U+00c7}2",
    "\N{U+00c7}3",
    "\N{U+00c7}4",
  ],
  quarter_stand_alone_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_stand_alone_wide => [
    "\N{U+00c7}ar\N{U+00ea}ka 1em",
    "\N{U+00c7}ar\N{U+00ea}ka 2em",
    "\N{U+00c7}ar\N{U+00ea}ka 3em",
    "\N{U+00c7}ar\N{U+00ea}ka 4em",
  ],
  script => undef,
  territory => undef,
  time_format_full => "HH:mm:ss zzzz",
  time_format_long => "HH:mm:ss z",
  time_format_medium => "HH:mm:ss",
  time_format_short => "HH:mm",
  variant => undef,
  version => 42,
}
